]> git.rm.cloudns.org Git - xonotic/darkplaces.git/commitdiff
Fix various typos: dont -> don't, doesnt -> doesn't, arguements -> arguments
authorSimon McVittie <smcv@debian.org>
Fri, 20 Jan 2012 09:34:00 +0000 (09:34 +0000)
committernyov <nyov@nexnode.net>
Thu, 27 Nov 2014 10:32:11 +0000 (10:32 +0000)
Picked up by Debian's Lintian package-checking tool.

Origin: vendor, Debian

19 files changed:
clvm_cmds.c
cmd.c
dpdefs/csprogsdefs.qc
gl_draw.c
gl_rmain.c
gl_textures.c
menu.c
netconn.c
progsvm.h
prvm_cmds.c
prvm_edict.c
r_sprites.c
sbar.c
svvm_cmds.c
sys.h
todo
vid_sdl.c
vid_wgl.c
world.c

index 6ca2749c89746e45e64f2fe6c918ce2e9c839a29..7d8027ce5ecdace2f0347b1c1bb9d84d963d580b 100644 (file)
@@ -472,7 +472,7 @@ static void VM_CL_findradius (prvm_prog_t *prog)
        else
                chainfield = prog->fieldoffsets.chain;
        if(chainfield < 0)
-               prog->error_cmd("VM_findchain: %s doesnt have the specified chain field !", prog->name);
+               prog->error_cmd("VM_findchain: %s doesn't have the specified chain field !", prog->name);
 
        chain = (prvm_edict_t *)prog->edicts;
 
diff --git a/cmd.c b/cmd.c
index ea486140bce595ec383ce744b6c6630fe254dc73..4b5dc6970708f4d1a087e9c90cb1ce436f6028d7 100644 (file)
--- a/cmd.c
+++ b/cmd.c
@@ -1615,7 +1615,7 @@ static void Cmd_TokenizeString (const char *text)
                        l = (int)strlen(com_token) + 1;
                        if (cmd_tokenizebufferpos + l > CMD_TOKENIZELENGTH)
                        {
-                               Con_Printf("Cmd_TokenizeString: ran out of %i character buffer space for command arguements\n", CMD_TOKENIZELENGTH);
+                               Con_Printf("Cmd_TokenizeString: ran out of %i character buffer space for command arguments\n", CMD_TOKENIZELENGTH);
                                break;
                        }
                        memcpy (cmd_tokenizebuffer + cmd_tokenizebufferpos, com_token, l);
index c9b9ce9cbc358056fa13b34169ac04c5c015559c..6d2cb422ed33cfdb27e3e0e186a3f4fc5e9aa517 100644 (file)
@@ -797,8 +797,8 @@ float(float entitynum, float fldnum) getentity = #504;
 vector(float entitynum, float fldnum) getentityvec = #504;
 // description: allows to query parms from render entities, especially useful with attaching CSQC ents to
 // server entities networked and interpolated by engine (monsters, players), number of entity is it's SVQC number
-// you can send it via tempentity/CSQC entity message. Note that this builtin doesnt know about entity removing/reallocating
-// so it's meaning to work for short period of time, dont use it on missiles/grenades whatever will be removed next five seconds
+// you can send it via tempentity/CSQC entity message. Note that this builtin doesn't know about entity removing/reallocating
+// so it's meaning to work for short period of time, don't use it on missiles/grenades whatever will be removed next five seconds
 
 //DP_GFX_FONTS
 //idea: Blub\0, divVerent
index 88431d9a83e206deeb34ae1cc6d1467889d4e317..fb3df8d0c98e7240013b93c1011559ea9249d44b 100644 (file)
diff --git a/menu.c b/menu.c
index 184ae366dc96c75b2aff943c6841f85c5f8afab8..49546720a3ea7fa2aba60f6e828a563d43087cff 100644 (file)
--- a/menu.c
+++ b/menu.c
@@ -3220,7 +3220,7 @@ static int M_ChooseQuitMessage(int request)
                if (request-- == 0) return M_QuitMessage("All your quit are","belong to long duck","dong",NULL,NULL,NULL,NULL,NULL);
                if (request-- == 0) return M_QuitMessage("Press Y to quit","","But are you too legit?",NULL,NULL,NULL,NULL,NULL);
                if (request-- == 0) return M_QuitMessage("This game was made by","e@chip-web.com","It is by far the best","game ever made.",NULL,NULL,NULL,NULL);
-               if (request-- == 0) return M_QuitMessage("Even I really dont","know of a game better","Press Y to quit","like rougue chedder",NULL,NULL,NULL,NULL);
+               if (request-- == 0) return M_QuitMessage("Even I really don't","know of a game better","Press Y to quit","like rougue chedder",NULL,NULL,NULL,NULL);
                if (request-- == 0) return M_QuitMessage("After you stop playing","tell the guys who made","counterstrike to just","kill themselves now",NULL,NULL,NULL,NULL);
                if (request-- == 0) return M_QuitMessage("Press Y to exit to DOS","","SSH login as user Y","to exit to Linux",NULL,NULL,NULL,NULL);
                if (request-- == 0) return M_QuitMessage("Press Y like you","were waanderers","from Ys'",NULL,NULL,NULL,NULL,NULL);
index aa8bf94aeef06c1447d8fc62d5fd1c74fcb96596..4be249237db1e6f65ef486aedb5327f7dc82ed0c 100755 (executable)
--- a/netconn.c
+++ b/netconn.c
@@ -1494,7 +1494,7 @@ static int NetConn_ClientParsePacket_ServerList_ProcessReply(const char *address
 
        if (n == serverlist_cachecount)
        {
-               // LAN search doesnt require an answer from the master server so we wont
+               // LAN search doesn't require an answer from the master server so we wont
                // know the ping nor will it be initialized already...
 
                // find a slot
@@ -1526,7 +1526,7 @@ static int NetConn_ClientParsePacket_ServerList_ProcessReply(const char *address
                entry->query = SQS_QUERIED;
        } else {
                // convert to unsigned to catch the -1
-               // I still dont like this but its better than the old 10000 magic ping number - as in easier to type and read :( [11/8/2007 Black]
+               // I still don't like this but its better than the old 10000 magic ping number - as in easier to type and read :( [11/8/2007 Black]
                entry->info.ping = min((unsigned) entry->info.ping, (unsigned) pingtime);
                serverreplycount++;
        }
index 406a9eb21cf5bfdaea156f931097fc6bf5e61f80..24525346bd71c857be6fe9eb3bdebba768e005c7 100644 (file)
diff --git a/sbar.c b/sbar.c
index 43888d5e6d6b18261313740a2e2217cf990c0575..4cec184f50f48848d8c4acdd3b2273245a91a7ba 100644 (file)
--- a/sbar.c
+++ b/sbar.c
@@ -1506,7 +1506,7 @@ void Sbar_Draw (void)
                                else
                                        Sbar_DrawXNum((154-3*24),12,cl.stats[STAT_HEALTH],3,24,0.6,0.7,0.8,1,0);
 
-                               // AK dont draw ammo for the laser
+                               // AK don't draw ammo for the laser
                                if(cl.stats[STAT_ACTIVEWEAPON] != 12)
                                {
                                        if (cl.stats[STAT_ITEMS] & NEX_IT_SHELLS)
index e9d51fdf75df165ac94bd4f451447b1c88067e61..64e1cd6387f556d5c041769ac0968ff892512377 100644 (file)
@@ -995,7 +995,7 @@ static void VM_SV_findradius(prvm_prog_t *prog)
        else
                chainfield = prog->fieldoffsets.chain;
        if (chainfield < 0)
-               prog->error_cmd("VM_findchain: %s doesnt have the specified chain field !", prog->name);
+               prog->error_cmd("VM_findchain: %s doesn't have the specified chain field !", prog->name);
 
        chain = (prvm_edict_t *)prog->edicts;
 
diff --git a/sys.h b/sys.h
index e5247d351afabe274f3e1a933b5915b89bc5b199..862bdf7c1675fd0fc18d53e53cd2ba62e27f9685 100644 (file)
--- a/sys.h
+++ b/sys.h
@@ -74,7 +74,7 @@ void Sys_Error (const char *error, ...) DP_FUNC_PRINTF(1) DP_FUNC_NORETURN;
 void Sys_PrintToTerminal(const char *text);
 void Sys_PrintfToTerminal(const char *fmt, ...);
 
-/// INFO: This is only called by Host_Shutdown so we dont need testing for recursion
+/// INFO: This is only called by Host_Shutdown so we don't need testing for recursion
 void Sys_Shutdown (void);
 void Sys_Quit (int returnvalue);
 
diff --git a/todo b/todo
index adfa4ebecf3f2e5722cc6a7bc139ab6e7db7caa2..08257b44313e2c215779613d452bea19721ecc4a 100644 (file)
--- a/todo
+++ b/todo
 2 feature darkplaces client: decal clipping (romi)
 2 feature darkplaces client: http download and parse http://www.gameaholic.com/servers/qspy-quake for nq servers (Spike)
 2 feature darkplaces client: interpolate scale and alpha changes (Cheapy)
-2 feature darkplaces client: make CL_Video use TEXF_FRAGMENT again by adding general, transparent support for it in all drawqueue functions (so you dont need to call FragmentLocation) (Black)
+2 feature darkplaces client: make CL_Video use TEXF_FRAGMENT again by adding general, transparent support for it in all drawqueue functions (so you don't need to call FragmentLocation) (Black)
 2 feature darkplaces image: add scaling capabilities to Image_CopyMux
 2 feature darkplaces loader: add support for fuhquake naming of map textures (textures/start/quake.tga style)
 2 feature darkplaces loader: implement vertex cache optimization of models during loading, see this paper: http://home.comcast.net/~tom_forsyth/papers/fast_vert_cache_opt.html (Dresk)
@@ -1437,4 +1437,4 @@ f feature dpmod: include .lit and .dlit files for all id1 maps - this idea was r
 f feature dpmod: include .vis files for all id1 maps - this idea rejected due to lack of .vis support and download size
 f hqbsp: CreateBrushFaces should use RadiusFromBounds for its rotation box code, but hmap is obsolete (Vic)
 f optimization darkplaces renderer: change water distortion textures from multiple 2D textures to one 3D texture for smoother animation (Tomaz)
-f optimization darkplaces visibility: R_Q3BSP_RecursiveWorldNode should take clipflags parameter and do not cull a node against a plane if the parent node is totally on one side of the plane (Vic)
\ No newline at end of file
+f optimization darkplaces visibility: R_Q3BSP_RecursiveWorldNode should take clipflags parameter and do not cull a node against a plane if the parent node is totally on one side of the plane (Vic)
index 0aba7111c4fbfdd7bd4e388a0061d9fdb507c833..b3d46ba99208d1f158e38aa51c2086160e65254c 100644 (file)
--- a/vid_sdl.c
+++ b/vid_sdl.c
@@ -1712,7 +1712,7 @@ void VID_EnableJoystick(qboolean enable)
 }
 
 #if SDL_MAJOR_VERSION == 1
-// set the icon (we dont use SDL here since it would be too much a PITA)
+// set the icon (we don't use SDL here since it would be too much a PITA)
 #ifdef WIN32
 #include "resource.h"
 #include <SDL_syswm.h>
index ffa665891a6bc5b7ce9d65ad4f9eefebff379129..d6e8e8c0abeca896f18c62b0db85fb2c14beb2c1 100644 (file)
--- a/vid_wgl.c
+++ b/vid_wgl.c
@@ -496,7 +496,7 @@ void AppActivate(BOOL fActive, BOOL minimize)
        }
 }
 
-//TODO: move it around in vid_wgl.c since I dont think this is the right position
+//TODO: move it around in vid_wgl.c since I don't think this is the right position
 void Sys_SendKeyEvents (void)
 {
        MSG msg;
diff --git a/world.c b/world.c
index 1f96eae5b6ba8d684f8caff819505a336499b70c..f14913c0a2e3ae0523cceb2d4ecc26377d74a7c6 100644 (file)
--- a/world.c
+++ b/world.c
@@ -361,8 +361,8 @@ cvar_t physics_ode_world_damping_angular = {0, "physics_ode_world_damping_angula
 cvar_t physics_ode_world_damping_angular_threshold = {0, "physics_ode_world_damping_angular_threshold", "0.1", "world angular damping threshold (see ODE User Guide); use defaults when set to -1"};
 cvar_t physics_ode_world_gravitymod = {0, "physics_ode_world_gravitymod", "1", "multiplies gravity got from sv_gravity, this may be needed to tweak if strong damping is used"};
 cvar_t physics_ode_iterationsperframe = {0, "physics_ode_iterationsperframe", "1", "divisor for time step, runs multiple physics steps per frame"};
-cvar_t physics_ode_constantstep = {0, "physics_ode_constantstep", "0", "use constant step instead of variable step which tends to increase stability, if set to 1 uses sys_ticrate, instead uses it's own value"};
-cvar_t physics_ode_autodisable = {0, "physics_ode_autodisable", "1", "automatic disabling of objects which dont move for long period of time, makes object stacking a lot faster"};
+cvar_t physics_ode_constantstep = {0, "physics_ode_constantstep", "0", "use constant step instead of variable step which tends to increase stability, if set to 1 uses sys_ticrate, instead uses its own value"};
+cvar_t physics_ode_autodisable = {0, "physics_ode_autodisable", "1", "automatic disabling of objects which don't move for long period of time, makes object stacking a lot faster"};
 cvar_t physics_ode_autodisable_steps = {0, "physics_ode_autodisable_steps", "10", "how many steps object should be dormant to be autodisabled"};
 cvar_t physics_ode_autodisable_time = {0, "physics_ode_autodisable_time", "0", "how many seconds object should be dormant to be autodisabled"};
 cvar_t physics_ode_autodisable_threshold_linear = {0, "physics_ode_autodisable_threshold_linear", "0.6", "body will be disabled if it's linear move below this value"};
--- a/gl_draw.c
+++ b/gl_draw.c
@@ -872,7 +872,7 @@ static void LoadFont_f(void)
                           "loadfont console gfx/conchars,gfx/fallback 8 12 16 24 32\n"
                           "In many cases, 8 12 16 24 32 should be a good choice.\n"
                           "custom switches:\n"
-                          " scale x : scale all characters by this amount when rendering (doesnt change line height)\n"
+                          " scale x : scale all characters by this amount when rendering (doesn't change line height)\n"
                           " voffset x : offset all chars vertical when rendering, this is multiplied to character height\n"
                        );
                return;
index 1ab7aaa2fa3451ac80d4e13b24b92d9fe21f9d81..9596fd7ac36ca400890c3d240893fb8d3462a0ad 100644 (file)
@@ -3261,7 +3261,7 @@ skinframe_t *R_SkinFrame_Find(const char *name, int textureflags, int comparewid
        {
                rtexture_t *dyntexture;
                // check whether its a dynamic texture
// this only needs to be done because Purge doesnt delete skinframes - only sets the texture pointers to NULL and we need to restore it before returing.. [11/29/2007 Black]
                dyntexture = CL_GetDynTexture( basename );
                item->base = dyntexture; // either NULL or dyntexture handle
        }
index 2dd11ebf52f6d9ade26f4491a018dd0c8ba9dac5..3fb714187a46a2c2cc1acef656aacb7d819d9211 100644 (file)
@@ -307,7 +307,7 @@ void R_MarkDirtyTexture(rtexture_t *rt) {
                return;
        }
 
-       // dont do anything if the texture is already dirty (and make sure this *is* a dynamic texture after all!)
+       // don't do anything if the texture is already dirty (and make sure this *is* a dynamic texture after all!)
        if (glt->flags & GLTEXF_DYNAMIC)
        {
                // mark it as dirty, so R_RealGetTexture gets called
@@ -3261,7 +3261,7 @@ skinframe_t *R_SkinFrame_Find(const char *name, int textureflags, int comparewid
                rtexture_t *dyntexture;
                // check whether its a dynamic texture
-               // this only needs to be done because Purge doesnt delete skinframes - only sets the texture pointers to NULL and we need to restore it before returing.. [11/29/2007 Black]
+               // this only needs to be done because Purge doesn't delete skinframes - only sets the texture pointers to NULL and we need to restore it before returing.. [11/29/2007 Black]
                dyntexture = CL_GetDynTexture( basename );
                item->base = dyntexture; // either NULL or dyntexture handle
--- a/progsvm.h
+++ b/progsvm.h
@@ -65,7 +65,7 @@ typedef struct prvm_required_field_s
 } prvm_required_field_t;
 
 
-// AK: I dont call it engine private cause it doesnt really belongs to the engine
+// AK: I don't call it engine private because it doesn't really belong to the engine,
 //     it belongs to prvm.
 typedef struct prvm_edict_private_s
 {
index c9f5527966a790c4425a674193fe66484edfae6a..3b6b9e3897511bd1632fb89123555b0896bf7613 100644 (file)
@@ -1104,7 +1104,7 @@ void VM_findchain(prvm_prog_t *prog)
        else
                chainfield = prog->fieldoffsets.chain;
        if (chainfield < 0)
-               prog->error_cmd("VM_findchain: %s doesnt have the specified chain field !", prog->name);
+               prog->error_cmd("VM_findchain: %s doesn't have the specified chain field !", prog->name);
 
        chain = prog->edicts;
 
@@ -1159,7 +1159,7 @@ void VM_findchainfloat(prvm_prog_t *prog)
        else
                chainfield = prog->fieldoffsets.chain;
        if (chainfield < 0)
-               prog->error_cmd("VM_findchain: %s doesnt have the specified chain field !", prog->name);
+               prog->error_cmd("VM_findchain: %s doesn't have the specified chain field !", prog->name);
 
        chain = (prvm_edict_t *)prog->edicts;
 
@@ -1245,7 +1245,7 @@ void VM_findchainflags(prvm_prog_t *prog)
        else
                chainfield = prog->fieldoffsets.chain;
        if (chainfield < 0)
-               prog->error_cmd("VM_findchain: %s doesnt have the specified chain field !", prog->name);
+               prog->error_cmd("VM_findchain: %s doesn't have the specified chain field !", prog->name);
 
        chain = (prvm_edict_t *)prog->edicts;
 
@@ -4927,7 +4927,7 @@ void VM_buf_implode (prvm_prog_t *prog)
 /*
 ========================
 VM_bufstr_get
-get a string from buffer, returns tempstring, dont str_unzone it!
+get a string from buffer, returns tempstring, don't str_unzone it!
 string bufstr_get(float bufhandle, float string_index) = #465;
 ========================
 */
index 191197f5fed5ae1c49b591b8d9496a90028a9332..7014cbec151406cce93f6c7f93b86697f23b0c28 100644 (file)
@@ -248,8 +248,8 @@ prvm_edict_t *PRVM_ED_Alloc(prvm_prog_t *prog)
        int i;
        prvm_edict_t *e;
 
// the client qc dont need maxclients
// thus it doesnt need to use svs.maxclients
        // AK:  changed i=svs.maxclients+1
        // AK:  changed so the edict 0 wont spawn -> used as reserved/world entity
        //              although the menu/client has no world
@@ -289,7 +289,7 @@ FIXME: walk all entities and NULL out references to this entity
 */
 void PRVM_ED_Free(prvm_prog_t *prog, prvm_edict_t *ed)
 {
// dont delete the null entity (world) or reserved edicts
        if (ed - prog->edicts <= prog->reserved_edicts)
                return;
 
index a45a3e73b5ddaefe8a3535b906903033b143c155..dbd04c81da65c5c15b83fafce7e25de7f4e16b2c 100644 (file)
@@ -394,7 +394,7 @@ static void R_Model_Sprite_Draw_TransparentCallback(const entity_render_t *ent,
                
                        // lit sprite by lightgrid if it is not fullbright, lit only ambient
                        if (!(texture->currentmaterialflags & MATERIALFLAG_FULLBRIGHT))
-                               VectorAdd(ent->modellight_ambient, ent->modellight_diffuse, rsurface.modellight_ambient); // sprites dont use lightdirection
+                               VectorAdd(ent->modellight_ambient, ent->modellight_diffuse, rsurface.modellight_ambient); // sprites don't use lightdirection
 
                        // SPR_LABEL should not use depth test AT ALL
                        if(model->sprite.sprnum_type == SPR_LABEL || model->sprite.sprnum_type == SPR_LABEL_SCALE)
@@ -248,8 +248,8 @@ prvm_edict_t *PRVM_ED_Alloc(prvm_prog_t *prog)
        prvm_edict_t *e;
 
-       // the client qc dont need maxclients
-       // thus it doesnt need to use svs.maxclients
+       // the client qc doesn't need maxclients
+       // thus it doesn't need to use svs.maxclients
        // AK:  changed i=svs.maxclients+1
        // AK:  changed so the edict 0 wont spawn -> used as reserved/world entity
@@ -289,7 +289,7 @@ FIXME: walk all entities and NULL out references to this entity
 void PRVM_ED_Free(prvm_prog_t *prog, prvm_edict_t *ed)
 {
-       // dont delete the null entity (world) or reserved edicts
+       // don't delete the null entity (world) or reserved edicts
        if (ed - prog->edicts <= prog->reserved_edicts)
                return;